==> deepin-manual_5.8.3.orig.tar.xz: deepin-manual-5.8.3/translations/deepin-manual_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>ManualProxy</name>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="306"/>
        <source>Desktop Environment</source>
        <translation>Desktop Environment</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/app/dman.cpp" line="71"/>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="72"/>
        <source>Manual is designed to help users learn the operating system and its applications, providing specific instructions and function descriptions.</source>
        <translation>Manual nasce per aiutare l&apos;utenza all&apos;utilizzo del Sistema Operativo ed alle Applicazioni native, fornendo istruzioni specifiche e descrivendo le singole funzionalità.
Localizzazione italiana a cura di Massimo A. Carofano.</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="34"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="35"/>
        <source>Applications</source>
        <translation>Applicazioni</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="38"/>
        <source>No search results</source>
        <translation>Nessun risultato</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="41"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="43"/>
        <source>  result</source>
        <translation>risultato</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="44"/>
        <source>  results</source>
        <translation>risultati</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="513"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="516"/>
        <source>Support</source>
        <translation>Supporto</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="250"/>
        <source>The content was updated</source>
        <translation>Il contenuto è stato aggiornato</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="691"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="../src/view/widget/search_completion_window.cpp" line="174"/>
        <location filename="../src/view/widget/search_completion_window.cpp" line="259"/>
        <source>Search for &quot;%1&quot; in the full text</source>
        <translation>Ricerca di &quot;%1&quot; anche nei contenuti</translation>
    </message>
</context>
<context>
    <name>WebWindow</name>
    <message>
        <location filename="../src/view/web_window.cpp" line="616"/>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="641"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
</context>
</TS>

==> deepin-manual_6.0.5.orig.tar.xz: deepin-manual-6.0.5/translations/deepin-manual_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>ManualProxy</name>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="311"/>
        <source>Desktop Environment</source>
        <translation>Desktop Environment</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/app/dman.cpp" line="107"/>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="108"/>
        <source>Manual is designed to help users learn the operating system and its applications, providing specific instructions and function descriptions.</source>
        <translation>Manual nasce per aiutare l&apos;utenza all&apos;utilizzo del Sistema Operativo ed alle Applicazioni native, fornendo istruzioni specifiche e descrivendo le singole funzionalità.
Localizzazione italiana a cura di Massimo A. Carofano.</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="21"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="22"/>
        <source>Applications</source>
        <translation>Applicazioni</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
        <source>No search results</source>
        <translation>Nessun risultato</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
        <source>  result</source>
        <translation>risultato</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
        <source>  results</source>
        <translation>risultati</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="591"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="594"/>
        <source>Support</source>
        <translation>Supporto</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="275"/>
        <source>The content was updated</source>
        <translation>Il contenuto è stato aggiornato</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="795"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="../src/view/widget/search_completion_window.cpp" line="163"/>
        <location filename="../src/view/widget/search_completion_window.cpp" line="249"/>
        <source>Search for &quot;%1&quot; in the full text</source>
        <translation>Ricerca di &quot;%1&quot; anche nei contenuti</translation>
    </message>
</context>
<context>
    <name>WebWindow</name>
    <message>
        <location filename="../src/view/web_window.cpp" line="729"/>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="744"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
</context>
</TS>
